@@ -225,7 +225,7 @@ class BaseGeometry(object):
         if not self._is_empty and not self._other_owned and self.__geom__:
             try:
                 self._lgeos.GEOSGeom_destroy(self.__geom__)
-            except AttributeError:
+            except (AttributeError, TypeError):
                 pass  # _lgeos might be empty on shutdown
         self._is_empty = True
         self.__geom__ = val
@@ -699,7 +699,11 @@ class BaseGeometry(object):
         return bool(self.impl['disjoint'](self, other))
 
     def equals(self, other):
-        """Returns True if geometries are equal, else False"""
+        """Returns True if geometries are equal, else False
+        
+        Refers to point-set equality (or topological equality), and is equivalent to
+        (self.within(other) & self.contains(other))
+        """
         return bool(self.impl['equals'](self, other))
 
     def intersects(self, other):
@@ -720,12 +724,20 @@ class BaseGeometry(object):
 
     def equals_exact(self, other, tolerance):
         """Returns True if geometries are equal to within a specified
-        tolerance"""
+        tolerance
+        
+        Refers to coordinate equality, which requires coordinates to be equal 
+        and in the same order for all components of a geometry
+        """
         return bool(self.impl['equals_exact'](self, other, tolerance))
 
     def almost_equals(self, other, decimal=6):
         """Returns True if geometries are equal at all coordinates to a
-        specified decimal place"""
+        specified decimal place
+
+        Refers to approximate coordinate equality, which requires coordinates be
+        approximately equal and in the same order for all components of a geometry.
+        """
         return self.equals_exact(other, 0.5 * 10**(-decimal))
 
     def relate_pattern(self, other, pattern):
@@ -943,6 +955,12 @@ class HeterogeneousGeometrySequence(GeometrySequence):
         return g
 
 
+class EmptyGeometry(BaseGeometry):
+    def __init__(self):
+        """Create an empty geometry."""
+        BaseGeometry.__init__(self)
+
+
 def _test():
     """Test runner"""
     import doctest
