@@ -8,7 +8,6 @@ if sys.version_info[0] < 3:
 
 from ctypes import c_double, cast, POINTER
 
-from shapely.coords import required
 from shapely.geos import lgeos, TopologicalError
 from shapely.geometry.base import (
     BaseGeometry, geom_factory, JOIN_STYLE, geos_geom_from_py
@@ -84,14 +83,20 @@ class LineString(BaseGeometry):
 
     def array_interface(self):
         """Provide the Numpy array protocol."""
-        return self.coords.array_interface()
+        if self.is_empty:
+            ai = {'version': 3, 'typestr': '<f8', 'shape': (0,), 'data': (c_double * 0)()}
+        else:
+            ai = self.coords.array_interface()
+        return ai
 
     __array_interface__ = property(array_interface)
 
     # Coordinate access
     def _set_coords(self, coordinates):
         self.empty()
-        self._geom, self._ndim = geos_linestring_from_py(coordinates)
+        ret = geos_linestring_from_py(coordinates)
+        if ret is not None:
+            self._geom, self._ndim = ret
 
     coords = property(BaseGeometry._get_coords, _set_coords)
 
@@ -119,9 +124,8 @@ class LineString(BaseGeometry):
         The side parameter may be 'left' or 'right' (default is 'right'). The
         resolution of the buffer around each vertex of the object increases by
         increasing the resolution keyword parameter or third positional
-        parameter. If the distance parameter is negative the side is inverted,
-        e.g. distance=5.0, side='left' is the same as distance=-5.0,
-        side='right'.
+        parameter. Vertices of right hand offset lines will be ordered in
+        reverse.
 
         The join style is for outside corners between line segments. Accepted
         values are JOIN_STYLE.round (1), JOIN_STYLE.mitre (2), and
@@ -132,7 +136,8 @@ class LineString(BaseGeometry):
         When two line segments meet at a sharp angle, a miter join will extend
         far beyond the original geometry. To prevent unreasonable geometry, the
         mitre limit allows controlling the maximum length of the join corner.
-        Corners with a ratio which exceed the limit will be beveled."""
+        Corners with a ratio which exceed the limit will be beveled.
+        """
         if mitre_limit == 0.0:
             raise ValueError(
                 'Cannot compute offset from zero-length line segment')
@@ -185,113 +190,64 @@ def asLineString(context):
 
 def geos_linestring_from_py(ob, update_geom=None, update_ndim=0):
     # If a LineString is passed in, clone it and return
-    # If a LinearRing is passed in, clone the coord seq and return a LineString
+    # If a LinearRing is passed in, clone the coord seq and return a
+    # LineString.
+    #
+    # NB: access to coordinates using the array protocol has been moved
+    # entirely to the speedups module.
+
     if isinstance(ob, LineString):
         if type(ob) == LineString:
             return geos_geom_from_py(ob)
         else:
             return geos_geom_from_py(ob, lgeos.GEOSGeom_createLineString)
 
-    # If numpy is present, we use numpy.require to ensure that we have a
-    # C-continguous array that owns its data. View data will be copied.
-    ob = required(ob)
     try:
-        # From array protocol
-        array = ob.__array_interface__
-        assert len(array['shape']) == 2
-        m = array['shape'][0]
-        if m < 2:
-            raise ValueError(
-                "LineStrings must have at least 2 coordinate tuples")
-        try:
-            n = array['shape'][1]
-        except IndexError:
-            raise ValueError(
-                "Input %s is the wrong shape for a LineString" % str(ob))
-        assert n == 2 or n == 3
+        m = len(ob)
+    except TypeError:  # Iterators, e.g. Python 3 zip
+        ob = list(ob)
+        m = len(ob)
 
-        # Make pointer to the coordinate array
-        if isinstance(array['data'], tuple):
-            # numpy tuple (addr, read-only)
-            cp = cast(array['data'][0], POINTER(c_double))
+    if m == 0:
+        return None
+    elif m == 1:
+        raise ValueError("LineStrings must have at least 2 coordinate tuples")
+
+    def _coords(o):
+        if isinstance(o, Point):
+            return o.coords[0]
         else:
-            cp = array['data']
+            return o
 
-        # Create a coordinate sequence
-        if update_geom is not None:
-            cs = lgeos.GEOSGeom_getCoordSeq(update_geom)
-            if n != update_ndim:
-                raise ValueError(
-                    "Wrong coordinate dimensions; this geometry has "
-                    "dimensions: %d" % update_ndim)
-        else:
-            cs = lgeos.GEOSCoordSeq_create(m, n)
+    try:
+        n = len(_coords(ob[0]))
+    except TypeError:
+        raise ValueError(
+            "Input %s is the wrong shape for a LineString" % str(ob))
+    assert n == 2 or n == 3
 
-        # add to coordinate sequence
-        for i in range(m):
-            dx = c_double(cp[n*i])
-            dy = c_double(cp[n*i+1])
-            dz = None
-            if n == 3:
-                try:
-                    dz = c_double(cp[n*i+2])
-                except IndexError:
-                    raise ValueError("Inconsistent coordinate dimensionality")
-
-            # Because of a bug in the GEOS C API,
-            # always set X before Y
-            lgeos.GEOSCoordSeq_setX(cs, i, dx)
-            lgeos.GEOSCoordSeq_setY(cs, i, dy)
-            if n == 3:
-                lgeos.GEOSCoordSeq_setZ(cs, i, dz)
-
-    except AttributeError:
-        # Fall back on list
-        try:
-            m = len(ob)
-        except TypeError:  # Iterators, e.g. Python 3 zip
-            ob = list(ob)
-            m = len(ob)
-
-        if m < 2:
+    # Create a coordinate sequence
+    if update_geom is not None:
+        cs = lgeos.GEOSGeom_getCoordSeq(update_geom)
+        if n != update_ndim:
             raise ValueError(
-                "LineStrings must have at least 2 coordinate tuples")
+                "Wrong coordinate dimensions; this geometry has "
+                "dimensions: %d" % update_ndim)
+    else:
+        cs = lgeos.GEOSCoordSeq_create(m, n)
 
-        def _coords(o):
-            if isinstance(o, Point):
-                return o.coords[0]
-            else:
-                return o
-
-        try:
-            n = len(_coords(ob[0]))
-        except TypeError:
-            raise ValueError(
-                "Input %s is the wrong shape for a LineString" % str(ob))
-        assert n == 2 or n == 3
-
-        # Create a coordinate sequence
-        if update_geom is not None:
-            cs = lgeos.GEOSGeom_getCoordSeq(update_geom)
-            if n != update_ndim:
-                raise ValueError(
-                    "Wrong coordinate dimensions; this geometry has "
-                    "dimensions: %d" % update_ndim)
-        else:
-            cs = lgeos.GEOSCoordSeq_create(m, n)
-
-        # add to coordinate sequence
-        for i in range(m):
-            coords = _coords(ob[i])
-            # Because of a bug in the GEOS C API,
-            # always set X before Y
-            lgeos.GEOSCoordSeq_setX(cs, i, coords[0])
-            lgeos.GEOSCoordSeq_setY(cs, i, coords[1])
-            if n == 3:
-                try:
-                    lgeos.GEOSCoordSeq_setZ(cs, i, coords[2])
-                except IndexError:
-                    raise ValueError("Inconsistent coordinate dimensionality")
+    # add to coordinate sequence
+    for i in range(m):
+        coords = _coords(ob[i])
+        # Because of a bug in the GEOS C API,
+        # always set X before Y
+        lgeos.GEOSCoordSeq_setX(cs, i, coords[0])
+        lgeos.GEOSCoordSeq_setY(cs, i, coords[1])
+        if n == 3:
+            try:
+                lgeos.GEOSCoordSeq_setZ(cs, i, coords[2])
+            except IndexError:
+                raise ValueError("Inconsistent coordinate dimensionality")
 
     if update_geom is not None:
         return None
@@ -301,12 +257,3 @@ def geos_linestring_from_py(ob, update_geom=None, update_ndim=0):
 
 def update_linestring_from_py(geom, ob):
     geos_linestring_from_py(ob, geom._geom, geom._ndim)
-
-
-# Test runner
-def _test():
-    import doctest
-    doctest.testmod()
-
-if __name__ == "__main__":
-    _test()
